@@ -5,7 +5,7 @@ from PySide.QtCore import *
 from PySide.QtGui import *
 
 # Some global variables
-HandyGuiVersion = "0.0.1-1"
+HandyGuiVersion = "0.0.1-2"
 CommentChar = '#'
 OptionChar =  ' '
 Home = os.path.expanduser("~")
@@ -16,6 +16,8 @@ P1buttons = ""
 BiosPath = ""
 RomPath = ""
 ExecPath = ""
+gameName = ""
+
 
 def parse_config(self, filename):
         options = {}
@@ -47,6 +49,7 @@ class Ui_MainWindow(QMainWindow):
 	'''
 	Check for required files
 	'''
+	global gameName
 	# Load config
         self.gui_opts = parse_config(self,HandyGui_CfgFile)
 	if not "exec_path" in self.gui_opts:
@@ -76,43 +79,20 @@ class Ui_MainWindow(QMainWindow):
         backgroundLabel.setText(AboutTxt)
 	backgroundLabel.setAlignment(Qt.AlignCenter | Qt.AlignLeft)
       	self.setCentralWidget(backgroundLabel)
-        # Get Gametitles from rom_path
-	ListCmd = "cd '" + self.gui_opts["rom_path"] + "' 2>/dev/null;ls -1 *.zip *.ZIP *.LNX *.lnx 2>/dev/null|sort -f" 
-        fin,fout = os.popen4(ListCmd)
-        romList = fout.read()
-        fin.close()
-        romList = romList.split('\n')
-        romList = romList[:-1]
-        if not romList:
-                romList = ['No roms found']
 
-
-        self.combo = QComboBox(self)
-        self.combo.setStyleSheet( \
-	"QComboBox { color: gray; \
-	 border: 6px solid #045FB4; \
-	 border-radius: 3px; \
-	 min-width: 6em; \
-	 }" )
-	self.combo.setGeometry(QRect(20, 25, 750, 60))
+        self.gameListButton = QPushButton(self)
+	self.gameListButton.setGeometry(QRect(20, 25, 750, 60))
+	self.connect(self.gameListButton, SIGNAL("clicked()"), self.pickGame)
         # Read last started file
         try:
                 playedFile = open(LastPlayed_File,"r")
         except:
-                last_game = "dummy"
+                last_game = "Select game"
         else:
                 last_game = playedFile.readlines()
-        maxLength=63
-        for Game in romList:
-                space=""
-                spacecount=maxLength-len(Game)
-                for x in range(0,spacecount):
-                        space=space+" "
-                self.combo.addItem(space+Game)
-        self.GameFile=[[t] for t in romList if t]
-        # Set last file as current
-        if last_game[0] in romList:
-                self.combo.setCurrentIndex(romList.index(last_game[0]))
+		gameName = last_game
+
+	self.gameListButton.setText(''.join(last_game))
 
 	# Define menubar
 	aboutAction = QAction( '&About', self)
@@ -144,9 +124,14 @@ class Ui_MainWindow(QMainWindow):
             self.onesmutePushButton.setChecked(True)
 
 
+    def pickGame(self):
+	gamePick = GamePickDialog(self)
+        gamePick.show()
+	if gameName:
+		self.gameListButton.setText(gameName)
+
     def on_start_clicked(self):
-        gameNbr = self.combo.currentIndex()
-        self.gameFile = str(self.GameFile[gameNbr]).strip("['']")
+	# global gameName
 
 	# Add all the options
 	# but first, re-read all settings
@@ -161,15 +146,15 @@ class Ui_MainWindow(QMainWindow):
 		ALL_OPTS = ALL_OPTS + "-nofullscreen "
         else:  ALL_OPTS = ALL_OPTS + "-fullscreen "
 
-        if not (self.gameFile == "No roms found" ):
+        if not (gameName == "No roms found" ):
                 # Write as last played game
                 playedFile = open(LastPlayed_File,"w")
-                playedFile.write(self.gameFile)
+                playedFile.write(gameName)
                 playedFile.close()
                 # Start emulator with parameters
 		os.chdir(self.gui_opts["exec_path"])
-		print self.gui_opts["exec_path"] + "/handy_sdl " + '"' + self.gui_opts["rom_path"] + "/" + self.gameFile + '" ' + ALL_OPTS
-		QProcess.startDetached(self.gui_opts["exec_path"] + "/handy_sdl " + '"' + self.gui_opts["rom_path"] + "/" + self.gameFile + '" ' + ALL_OPTS)
+		print self.gui_opts["exec_path"] + "/handy_sdl " + '"' + self.gui_opts["rom_path"] + "/" + gameName + '" ' + ALL_OPTS
+		QProcess.startDetached(self.gui_opts["exec_path"] + "/handy_sdl " + '"' + self.gui_opts["rom_path"] + "/" + gameName + '" ' + ALL_OPTS)
 
 		if (self.gui_opts["exit_after_launch"] == "true"):
 			time.sleep(5)
@@ -183,6 +168,53 @@ class Ui_MainWindow(QMainWindow):
         a = ConfigWindow(self)
         a.show()
 
+class GamePickDialog(QWidget):
+    def __init__(self,parent):
+        super(GamePickDialog, self).__init__(parent)
+        self.d = QDialog(self)
+        self.d.setMinimumHeight(380)
+        self.d.setMaximumHeight(380)
+	self.d.setWindowTitle("[Select game]")
+        hbox = QGridLayout()
+        horizontalLayout = QGridLayout()
+        self.gameWidget = QListWidget()
+
+	# Load config
+        self.gui_opts = parse_config(self,HandyGui_CfgFile)
+        # Get Gametitles from rom_path
+	ListCmd = "cd '" + self.gui_opts["rom_path"] + "' 2>/dev/null;ls -1 *.zip *.ZIP *.LNX *.lnx 2>/dev/null|sort -f" 
+        fin,fout = os.popen4(ListCmd)
+        romList = fout.read()
+        fin.close()
+        romList = romList.split('\n')
+        romList = romList[:-1]
+        if not romList:
+                romList = ['No roms found']
+
+        for Game in romList:
+                item = QListWidgetItem(Game)
+                item.setTextAlignment(Qt.AlignCenter)
+                self.gameWidget.addItem(item)
+		if Game == gameName:
+			currItem = item
+
+        # Set last file as current
+        if gameName in romList:
+                self.gameWidget.setCurrentItem(currItem)
+
+        horizontalLayout.addWidget(self.gameWidget,0,0)
+        self.d.setLayout(hbox)
+        hbox.addLayout (horizontalLayout,0,0)
+
+        self.connect(self.gameWidget, SIGNAL("itemClicked(QListWidgetItem *)"), self.itemClicked)
+        self.d.exec_()
+
+    def itemClicked(self, item):
+	global gameName
+        gameName = item.text()
+        self.d.close()
+
+
 class AboutWindow(QMainWindow):
     def __init__(self, parent):
         QMainWindow.__init__(self, parent)
@@ -332,6 +364,8 @@ class keyWindow(QDialog):
         super(keyWindow, self).__init__(parent)
         self.setWindowTitle("Handy-gui button config")
 	LineNbr=1
+        self.setMinimumHeight(380)
+        self.setMaximumHeight(380)
         self.options = parse_config(self,Handy_KeyCfgFile)
 	# Layout
 	area = QScrollArea(self)
